# pdm-fabric: Fabric command shortcut for PDM

A plugin that gives you command shortcut for developing with [PDM](https://pdm.fming.dev/) and
[Fabric](https://www.fabfile.org).


## Requirements

Tested with PDM 2.1.X

## Install

`pdm plugin add pdm-fabric`

## Usage

### fab

Example: `pdm fab shell --env dev`

## Thanks to the following projects as the idea came from them not me

https://github.com/neutron-sync/pdm-django

https://github.com/pdm-project/pdm
